@@ -71,7 +71,15 @@ int mu_c_str_unescape_trans (char const *str, char const *trans,
 int mu_version_string_parse (char const *verstr, int version[3], char **endp);
 int mu_version_string_cmp (char const *a, char const *b, int ignoresuf, int *res);
 
-int mu_str_expand (char **output, char const *input, mu_assoc_t assoc);
+int mu_str_expand_unquote (char **output, char const *input, int unquote,
+			   mu_assoc_t assoc);
+static inline int
+mu_str_expand (char **output, char const *input, mu_assoc_t assoc) {
+  return mu_str_expand_unquote (output, input, 0, assoc);
+}
+
+int mu_str_vexpand_unquote (char **output, char const *input, int unquote,
+			    ...);
 int mu_str_vexpand (char **output, char const *input, ...);
 
 int mu_strtosize (char const *str, char **endp, size_t *ret_val);
