@@ -1,5 +1,5 @@
 /* opt.c -- general-purpose command line option parser
-   Copyright (C) 2016-2024 Free Software Foundation, Inc.
+   Copyright (C) 2016-2025 Free Software Foundation, Inc.
 
    GNU Mailutils is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public License as
@@ -154,16 +154,16 @@ fn_version (struct mu_parseopt *po, struct mu_option *opt, char const *unused)
 struct mu_option mu_default_options[] = {
   MU_OPTION_GROUP(""),
   { "help",    '?', NULL, MU_OPTION_IMMEDIATE, N_("give this help list"),
-    mu_c_string, NULL, fn_help },
+    mu_c_string, NULL, fn_help, NULL, DEFAULT_TEXT_DOMAIN },
   { "usage",   0,   NULL, MU_OPTION_IMMEDIATE, N_("give a short usage message"),
-    mu_c_string, NULL, fn_usage
+    mu_c_string, NULL, fn_usage, NULL, DEFAULT_TEXT_DOMAIN
   },
   MU_OPTION_END
 };
 
 struct mu_option mu_version_options[] = {
   { "version", 'V', NULL, MU_OPTION_IMMEDIATE, N_("print program version"),
-    mu_c_string, NULL, fn_version },
+    mu_c_string, NULL, fn_version, NULL, DEFAULT_TEXT_DOMAIN },
   MU_OPTION_END
 };
 
