@@ -1,5 +1,5 @@
 /* GNU Mailutils -- a suite of utilities for electronic mail
-   Copyright (C) 2004-2022 Free Software Foundation, Inc.
+   Copyright (C) 2004-2025 Free Software Foundation, Inc.
 
    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Lesser General Public
@@ -42,20 +42,22 @@ subdir_exists (const char *name, int subdir)
 {
   struct stat st;
   char *s;
-
+  int res;
+  
   s = mu_make_file_name (name, mu_maildir_subdir_name (subdir));
   if (!s)
     return ENOMEM; /* FIXME: error message */
   
   if (stat (s, &st) < 0)
-    return errno;
-
-  free (s);
+    res = errno;
+  else if (!S_ISDIR (st.st_mode))
+    res = ENOTDIR;
+  else
+    res = 0;
   
-  if (!S_ISDIR (st.st_mode))
-    return ENOTDIR;
+  free (s);
 
-  return 0;
+  return res;
 }
 
 static int
