@@ -32,7 +32,7 @@ script_register (const char *pattern)
 {
   mu_script_t scr;
   struct mda_script *p;
-  
+
   if (script_handler)
     scr = script_handler;
   else
@@ -45,7 +45,7 @@ script_register (const char *pattern)
   p = malloc (sizeof (*p));
   if (!p)
     return MU_ERR_FAILURE;
-  
+
   p->scr = scr;
   p->pat = pattern;
 
@@ -142,7 +142,7 @@ cb_script_pattern (void *data, mu_config_value_t *val)
 {
   if (mu_cfg_assert_value_type (val, MU_CFG_STRING))
     return 1;
-  
+
   switch (script_register (val->v.string))
     {
     case 0:
@@ -162,7 +162,7 @@ static int
 cb_debug (void *data, mu_config_value_t *val)
 {
   char *p;
-  
+
   if (mu_cfg_assert_value_type (val, MU_CFG_STRING))
     return 1;
   if (mu_script_debug_flags (val->v.string, &p))
@@ -179,7 +179,7 @@ struct mu_cfg_param mda_script_cfg[] = {
     /* TRANSLATORS: words to the right of : are keywords - do not translate */
     N_("arg: python|guile") },
   { "pattern", mu_cfg_callback, NULL, 0, cb_script_pattern,
-    N_("Set script pattern."), 
+    N_("Set script pattern."),
     N_("arg: glob") },
   { "debug", mu_cfg_callback, NULL, 0, cb_debug,
     N_("Set scripting debug level.  Argument is one or more "
@@ -242,7 +242,7 @@ apply_script (void *item, void *data)
 
   return rc;
 }
-  
+
 int
 mda_filter_message (mu_message_t msg, struct mu_auth_data *auth)
 {
@@ -251,18 +251,28 @@ mda_filter_message (mu_message_t msg, struct mu_auth_data *auth)
       mu_attribute_t attr;
       struct apply_script_closure clos;
       int rc;
-      
+
       clos.auth = auth;
       clos.msg = msg;
 
+      rc = mu_homedir_assert (auth->dir, auth->uid, auth->gid);
+      if (rc)
+	{
+	  mda_error (_("cannot set up user home directory %s: %s"),
+		     auth->dir, mu_strerror (errno));
+	  mda_switch_user_id (auth, 0);
+	  return MDA_FILTER_FAILURE;
+	}
+
       mu_message_get_attribute (msg, &attr);
       mu_attribute_unset_deleted (attr);
+
       if (mda_switch_user_id (auth, 1))
 	return MDA_FILTER_FAILURE;
 
       if (chdir (auth->dir))
 	{
-	  mda_error (_("can't change to directory %s: %s"),
+	  mda_error (_("cannot change to directory %s: %s"),
 		     auth->dir, mu_strerror (errno));
 	  mda_switch_user_id (auth, 0);
 	  return MDA_FILTER_FAILURE;
@@ -272,7 +282,7 @@ mda_filter_message (mu_message_t msg, struct mu_auth_data *auth)
 
       if (mda_switch_user_id (auth, 0))
 	return MDA_FILTER_FAILURE;
-      
+
       if (rc == 0)
 	{
 	  mu_attribute_t attr;
@@ -292,7 +302,7 @@ static struct mu_cfg_param filter_cfg_param[] = {
     /* TRANSLATORS: words to the right of : are keywords - do not translate */
     N_("arg: sieve|python|scheme") },
   { "pattern", mu_cfg_callback, NULL, 0, cb_script_pattern,
-    N_("Set script pattern."), 
+    N_("Set script pattern."),
     N_("arg: glob") },
   { NULL }
 };
