@@ -1,6 +1,5 @@
 /* GNU Mailutils -- a suite of utilities for electronic mail
-   Copyright (C) 1999-2005, 2007-2012, 2014-2017 Free Software
-   Foundation, Inc.
+   Copyright (C) 1999-2025 Free Software Foundation, Inc.
 
    GNU Mailutils is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
@@ -194,7 +193,7 @@ static struct mu_cfg_param pop3d_srv_param[] = {
     NULL, mu_offsetof (struct pop3d_srv_config, tls_mode), cb_tls,
     N_("Kind of TLS encryption to use for this server"),
     /* TRANSLATORS: words to the right of : are keywords - do not translate */
-    N_("arg: false|true|ondemand|stls|requred|connection") },
+    N_("arg: false|true|ondemand|stls|required|connection") },
   { "tls", mu_cfg_section,
     NULL, mu_offsetof (struct pop3d_srv_config, tls_conf) },
   { NULL }
@@ -232,6 +231,12 @@ static struct mu_cfg_param pop3d_cfg_param[] = {
     N_("arg: list") },  
     
   { "tls", mu_cfg_section, &global_tls_conf },
+  { "tls-mode", mu_cfg_callback,
+    &global_tls_mode, 0, cb_tls,
+    N_("Kind of TLS encryption to use for the inetd server"
+       " and all server blocks that lack the tls-mode statement."),
+    /* TRANSLATORS: words to the right of : are keywords - do not translate */
+    N_("arg: false|true|ondemand|stls|required|connection") },
   
 #ifdef ENABLE_LOGIN_DELAY
   { "login-delay", mu_c_time, &login_delay, 0, NULL,
@@ -331,25 +336,27 @@ pop3d_mainloop (int ifd, int ofd, struct pop3d_srv_config *cfg)
   /* FIXME: state should also be in the session? */
   
   /* Prepare the shared secret for APOP.  */
-  {
-    char *local_hostname;
+  if (apop_ok ())
+    {
+      char *local_hostname;
     
-    status = mu_get_host_name (&local_hostname);
-    if (status)
-      {
-        mu_diag_funcall (MU_DIAG_ERROR, "mu_get_host_name", NULL, status);
-        exit (EXIT_FAILURE);
-      }
+      status = mu_get_host_name (&local_hostname);
+      if (status)
+	{
+	  mu_diag_funcall (MU_DIAG_ERROR, "mu_get_host_name", NULL, status);
+	  exit (EXIT_FAILURE);
+	}
 
-    md5shared = mu_alloc (strlen (local_hostname) + 51);
+      md5shared = mu_alloc (strlen (local_hostname) + 51);
 
-    snprintf (md5shared, strlen (local_hostname) + 50, "<%u.%u@%s>", getpid (),
-	      (unsigned)time (NULL), local_hostname);
-    free (local_hostname);
-  }
-
-  /* Lets boogie.  */
-  pop3d_outf ("+OK POP3 Ready %s\n", md5shared);
+      snprintf (md5shared, strlen (local_hostname) + 50, "<%u.%u@%s>",
+		getpid (),
+		(unsigned)time (NULL), local_hostname);
+      free (local_hostname);
+      pop3d_outf ("+OK POP3 Ready %s\n", md5shared);
+    }
+  else
+    pop3d_outf ("+OK POP3 Ready\n");
 
   while (state != UPDATE && state != ABORT)
     {
@@ -392,91 +399,13 @@ pop3d_mainloop (int ifd, int ofd, struct pop3d_srv_config *cfg)
 
   return status;
 }
-
-static int
-set_strerr_flt ()
-{
-  mu_stream_t flt, trans[2];
-  int rc;
-  
-  rc = mu_stream_ioctl (mu_strerr, MU_IOCTL_TOPSTREAM, MU_IOCTL_OP_GET, trans);
-  if (rc == 0)
-    {
-      char sessidstr[10];
-      char *argv[] = { "inline-comment", NULL, "-S", NULL };
-
-      snprintf (sessidstr, sizeof sessidstr, "%08lx:", mu_session_id);
-      argv[1] = sessidstr;
-      rc = mu_filter_create_args (&flt, trans[0], "inline-comment", 3,
-				  (const char **)argv,
-				  MU_FILTER_ENCODE, MU_STREAM_WRITE);
-      mu_stream_unref (trans[0]);
-      if (rc == 0)
-	{
-	  mu_stream_set_buffer (flt, mu_buffer_line, 0);
-	  trans[0] = flt;
-	  trans[1] = NULL;
-	  rc = mu_stream_ioctl (mu_strerr, MU_IOCTL_TOPSTREAM,
-				MU_IOCTL_OP_SET, trans);
-	  mu_stream_unref (trans[0]);
-	  if (rc)
-	    mu_error (_("%s failed: %s"), "MU_IOCTL_SET_STREAM",
-		      mu_stream_strerror (mu_strerr, rc));
-	}
-      else
-	mu_error (_("cannot create log filter stream: %s"), mu_strerror (rc));
-    }
-  else
-    {
-      mu_error (_("%s failed: %s"), "MU_IOCTL_GET_STREAM",
-		mu_stream_strerror (mu_strerr, rc));
-    }
-  return rc;
-}
-
-static void
-clr_strerr_flt ()
-{
-  mu_stream_t flt, trans[2];
-  int rc;
-
-  rc = mu_stream_ioctl (mu_strerr, MU_IOCTL_TOPSTREAM, MU_IOCTL_OP_GET, trans);
-  if (rc == 0)
-    {
-      flt = trans[0];
-
-      rc = mu_stream_ioctl (flt, MU_IOCTL_TOPSTREAM, MU_IOCTL_OP_GET, trans);
-      if (rc == 0)
-	{
-	  mu_stream_unref (trans[0]);
-	  rc = mu_stream_ioctl (mu_strerr, MU_IOCTL_TOPSTREAM,
-				MU_IOCTL_OP_SET, trans);
-	  if (rc == 0)
-	    mu_stream_unref (flt);
-	}
-    }
-}
-
+
 int
 pop3d_connection (int fd, struct sockaddr *sa, int salen,
 		  struct mu_srv_config *pconf,
 		  void *data)
 {
-  struct pop3d_srv_config *cfg = (struct pop3d_srv_config *) pconf;
-  int rc;
-  
-  idle_timeout = pconf->timeout;
-  pop3d_transcript = pconf->transcript;
-
-  if (mu_log_session_id)
-    rc = set_strerr_flt ();
-  else
-    rc = 1;
-
-  pop3d_mainloop (fd, fd, cfg);
-
-  if (rc == 0)
-    clr_strerr_flt ();
+  pop3d_mainloop (fd, fd, (struct pop3d_srv_config *) pconf);
   return 0;
 }
 
@@ -496,6 +425,13 @@ set_dbm_safety ()
 }
 #endif
 
+static void
+pop3d_config_default (struct mu_srv_config *mcfg, void *data)
+{
+  mcfg->timeout = idle_timeout;
+  mcfg->transcript = pop3d_transcript;
+}
+
 int
 main (int argc, char **argv)
 {
@@ -519,10 +455,11 @@ main (int argc, char **argv)
   mu_m_server_set_config_size (server, sizeof (struct pop3d_srv_config));
   mu_m_server_set_conn (server, pop3d_connection);
   mu_m_server_set_prefork (server, mu_tcp_wrapper_prefork);
+  mu_m_server_set_config_default (server, pop3d_config_default);
   mu_m_server_set_mode (server, MODE_INTERACTIVE);
   mu_m_server_set_max_children (server, 20);
   /* FIXME mu_m_server_set_pidfile (); */
-  mu_m_server_set_default_port (server, 110);
+  mu_m_server_set_default_port (server, PORT_POP3);
   mu_m_server_set_timeout (server, 600);
   mu_m_server_set_strexit (server, mu_strexit);
   mu_m_server_cfg_init (server, pop3d_srv_param);
@@ -604,7 +541,32 @@ main (int argc, char **argv)
     {
       struct pop3d_srv_config cfg;
       memset (&cfg, 0, sizeof cfg);
-      cfg.tls_mode = tls_no;
+
+      idle_timeout = mu_m_server_timeout (server);
+
+      switch (stls_server_check (&cfg, "<inetd>"))
+	{
+	case MU_TLS_CONFIG_OK:
+	  if (mu_init_tls_libs ())
+	    status = EX_OK;
+	  else
+	    {
+	      mu_error (_("TLS is not configured, but requested in the "
+			  "configuration"));
+	      exit (EX_CONFIG);
+	    }
+	  break;
+
+	case MU_TLS_CONFIG_NULL:
+	  break;
+
+	case MU_TLS_CONFIG_UNSAFE:
+	  exit (EX_CONFIG);
+
+	default:
+	  exit (EX_UNAVAILABLE);
+	}
+
       /* Make sure we are in the root directory.  */
       chdir ("/");
       status = pop3d_mainloop (MU_STDIN_FD, MU_STDOUT_FD, &cfg);
