@@ -1,5 +1,5 @@
 /* GNU Mailutils -- a suite of utilities for electronic mail
-   Copyright (C) 1999-2024 Free Software Foundation, Inc.
+   Copyright (C) 1999-2025 Free Software Foundation, Inc.
 
    GNU Mailutils is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
@@ -43,6 +43,7 @@
 #include <mailutils/nls.h>
 #include <mailutils/tls.h>
 #include <mailutils/cli.h>
+#include <mailutils/cstr.h>
 #include <mailutils/mu_auth.h>
 
 #define D_DEFAULT "TPt"
@@ -70,7 +71,7 @@ sieve_setenv (void *item, void *data)
   mu_sieve_machine_t mach = data;
   int rc = mu_sieve_set_environ (mach, str, str + strlen (str) + 1);
   if (rc)
-    mu_error (_("can't set environment item %s: %s"),
+    mu_error (_("cannot set environment item %s: %s"),
 	      str, mu_strerror (rc));
   return 0;
 }
@@ -389,8 +390,8 @@ sieve_mailbox (mu_sieve_machine_t mach)
   if ((rc = mu_mailbox_create_default (&mbox, mbox_url)) != 0)
     {
       if (mbox)
-	mu_error (_("could not create mailbox `%s': %s"),
-		  mbox_url, mu_strerror (rc));
+	mu_error (_("could not create mailbox %s: %s"),
+		  mu_quotename (mbox_url), mu_strerror (rc));
       else
 	mu_error (_("could not create default mailbox: %s"),
 		  mu_strerror (rc));
@@ -435,8 +436,8 @@ sieve_mailbox (mu_sieve_machine_t mach)
       if ((e = mu_mailbox_expunge (mbox)) != 0)
 	{
 	  if (mbox)
-	    mu_error (_("expunge on mailbox `%s' failed: %s"),
-		      mbox_url, mu_strerror (e));
+	    mu_error (_("expunge on mailbox %s failed: %s"),
+		      mu_quotename (mbox_url), mu_strerror (e));
 	  else
 	    mu_error (_("expunge on default mailbox failed: %s"),
 		      mu_strerror (e));
